Module wgpu

Module wgpu 

Structs

BlendState
Describe the blend state of a render pipeline, within ColorTargetState.
Extent3d
Extent of a texture related operation.
TextureUsages
Different ways that you can use a texture.

Enums

FilterMode
Texel mixing mode when sampling between texels.
TextureFormat
Format in which a texture’s texels are stored in GPU memory.
VertexFormat
Vertex Format for a VertexAttribute (input).
VertexStepMode
Whether a vertex buffer is indexed by vertex or by instance.