Module wgpu

Module wgpu 

Structs

BlendState
Describe the blend state of a render pipeline, within ColorTargetState.
ShaderModule
Handle to a compiled shader module.

Enums

TextureFormat
Format in which a texture’s texels are stored in GPU memory.
VertexFormat
Vertex Format for a VertexAttribute (input).
VertexStepMode
Whether a vertex buffer is indexed by vertex or by instance.